normalize_document_with_options

Function normalize_document_with_options 

pub fn normalize_document_with_options(
    source: &str,
    parse_options: &ParseOptions,
) -> Result<String, Message>
Normalize a Markdown document using explicit parser options.

Use this for syntax beyond the default GitHub Flavored Markdown, front matter, and math support, such as MDX.

Errors

Returns an error if the Markdown syntax tree cannot be parsed or serialized.